/* globals describe, it, beforeEach */

const OutputFiles = require('../lib/output-files')
const rimraf = require('rimraf')
const pathLib = require('path')

const storagePath = '.nyc_output/js'
const storagePathTop = '.nyc_output'

require('chai').should()

describe('output-files', () => {
  beforeEach(cleanupCoverage)

  // we can use path.basename(path[, ext]).
  it('exposes a handler that appropriately handles colliding names', () => {
    const outputFiles = OutputFiles(require('./fixtures/block-else-not-covered.json'))

    // Since block-else-not-covered was generated by the above line, this
    // should make a new file with -1 appended to the name
    var newPath = outputFiles.rewritePath('./sample_js/block-else-not-covered-1.js')
    newPath.should.include(storagePath + '/block-else-not-covered-1.js')
  })

  it('handle multiple files with same name, and replace in json', () => {
    // Input from the fixture should be JSONified already
    const fixture = require('./fixtures/function-coverage-full-duplicate.json')
    const coverageInfo = OutputFiles(fixture).getTransformedCoverage()

    // Fixture should and output coverage should not be in the same place
    coverageInfo[0].url.should.not.eql(fixture[0].url)
    coverageInfo[1].url.should.not.eql(fixture[1].url)

    coverageInfo[0].url.should.eql(movedUrl(fixture[0].url))
    coverageInfo[1].url.should.eql(movedUrl(fixture[0].url.replace('.js', '-1.js')))
  })

  // call it something like indexHTML-inline-1.js
  it('appropriately handles only inline JavaScript', () => {
    const fixture = require('./fixtures/inline-script-coverage.json')
    const coverageInfo = OutputFiles(fixture).getTransformedCoverage()

    coverageInfo[0].url.should.include('puppeteerTemp-inline.js')
  })

  it('appropriately handles inline and external JavaScript', () => {
    const fixture = require('./fixtures/inline-and-external-script-coverage.json')
    const coverageInfo = OutputFiles(fixture).getTransformedCoverage()

    coverageInfo[0].url.should.eql(movedUrl(fixture[0].url))
    coverageInfo[1].url.should.include('puppeteerTemp-inline.js')
  })

  it('appropriately handles two cases of inline JavaScript', () => {
    const fixture = require('./fixtures/two-inline.json')
    const coverageInfo = OutputFiles(fixture).getTransformedCoverage()

    coverageInfo[0].url.should.include('puppeteerTemp-inline.js')
    coverageInfo[1].url.should.include('puppeteerTemp-inline-1.js')
  })

  function cleanupCoverage () {
    rimraf.sync(storagePathTop)
  }

  // Takes in a script and rewrites it to the path we expect in /coverage/js
  function movedUrl (url) {
    let splitUrl = url.split('/')

    // Prepend the folder to the filename
    return pathLib.resolve(storagePath, splitUrl[splitUrl.length - 1])
  }
})
